@@ -6,7 +6,10 @@ from brain_brew.representation.configuration.global_config import GlobalConfig
 class BuildTaskGeneric:
     @staticmethod
     def split_tags(tags_value: str) -> list:
-        return [entry.strip() for entry in re.split(';\s*|,\s*|\s+', tags_value)]
+        split = [entry.strip() for entry in re.split(';\s*|,\s*|\s+', tags_value)]
+        while "" in split:
+            split.remove("")
+        return split
 
     @staticmethod
     def join_tags(tags_list: list) -> str:
