@@ -1,4 +1,4 @@
-import logging
+from collections import OrderedDict
 from enum import Enum
 
 from brain_brew.build_tasks.build_task_generic import BuildTaskGeneric
@@ -8,7 +8,7 @@ from brain_brew.constants.deckpart_keys import DeckPartNoteKeys
 from brain_brew.file_manager import FileManager
 from brain_brew.representation.generic.media_file import MediaFile
 from brain_brew.utils import blank_str_if_none
-from brain_brew.representation.configuration.yaml_file import ConfigKey, YamlFile
+from brain_brew.representation.generic.yaml_file import ConfigKey, YamlFile
 from brain_brew.representation.json.crowd_anki_export import CrowdAnkiExport
 from brain_brew.representation.json.deck_part_header import DeckPartHeader
 from brain_brew.representation.json.deck_part_notemodel import CANoteModelKeys, DeckPartNoteModel
@@ -69,9 +69,6 @@ class SourceCrowdAnki(YamlFile, BuildTaskGeneric):
 
         return SourceCrowdAnki(config_data, read_now=read_now)
 
-    def extract_media(self):
-        raise NotImplementedError
-
     def notes_to_deck_parts(self, notes_json, note_models_id_name_dict):
         for note in notes_json:
             for key in self.useless_note_keys:
@@ -128,7 +125,7 @@ class SourceCrowdAnki(YamlFile, BuildTaskGeneric):
             note[CANoteKeys.NOTE_MODEL.value] = note_models_dict_id_name[note[DeckPartNoteKeys.NOTE_MODEL.value]]
             del note[DeckPartNoteKeys.NOTE_MODEL.value]
 
-        return res_notes
+        return [OrderedDict(sorted(note.items())) for note in res_notes]
 
     def deck_parts_to_source(self):
         ca_json = {}
@@ -160,4 +157,6 @@ class SourceCrowdAnki(YamlFile, BuildTaskGeneric):
         # Notes
         ca_json.setdefault(CAKeys.NOTES.value, self.notes_to_source(note_models_dict_id_name))
 
-        self.crowd_anki_export.set_data(ca_json)
+        ordered_keys = OrderedDict(sorted(ca_json.items()))
+
+        self.crowd_anki_export.set_data(ordered_keys)
