@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 
 from brain_brew.constants.deckpart_keys import NoteFlagKeys, DeckPartNoteFlags
 from brain_brew.constants.global_config_keys import *
-from brain_brew.representation.configuration.yaml_file import YamlFile, ConfigKey
+from brain_brew.representation.generic.yaml_file import YamlFile, ConfigKey
 
 
 @dataclass
@@ -23,7 +23,6 @@ class GlobalConfig(YamlFile):
         reverse_sort: bool = False
         join_values_with: str = " "
 
-    authors: object
     deck_parts: DeckPartConfig
     flags: ConfigFlags
     deck_part_notes_flags: DeckPartNoteFlags
@@ -31,7 +30,6 @@ class GlobalConfig(YamlFile):
 
     config_entry = {}
     expected_keys = {
-        ConfigKeys.AUTHORS.value: ConfigKey(False, list, None),
         ConfigKeys.DECK_PARTS.value: ConfigKey(True, dict, {
             ConfigKeys.HEADERS.value: ConfigKey(True, str, None),
             ConfigKeys.NOTE_MODELS.value: ConfigKey(True, str, None),
@@ -60,7 +58,6 @@ class GlobalConfig(YamlFile):
         self.setup_config_with_subconfig_replacement(config_data)
         self.verify_config_entry()
 
-        self.authors = self.get_config(ConfigKeys.AUTHORS, {})
         dp = self.get_config(ConfigKeys.DECK_PARTS)
         self.deck_parts = DeckPartConfig(
             dp[ConfigKeys.HEADERS.value], dp[ConfigKeys.NOTE_MODELS.value],
@@ -80,10 +77,12 @@ class GlobalConfig(YamlFile):
 
     @classmethod
     def get_default(cls):
-        global_config_name = "_config.yaml"
-        global_config_filepath = f"{global_config_name}"
+        global_config_name = "brain_brew_config.yaml"
+        return cls.from_yaml(global_config_name)
 
-        gb_config_yaml = YamlFile.read_file(global_config_filepath)
+    @classmethod
+    def from_yaml(cls, yaml_file):
+        gb_config_yaml = YamlFile.read_file(yaml_file)
 
         return GlobalConfig(gb_config_yaml)
 
